@@ -83,9 +83,32 @@ func New(mgr manager.Manager, config Config) (controller.Controller, error) {
 	if err := c.Watch(&source.Kind{Type: &iov1.DNSRecord{}}, &handler.EnqueueRequestForOwner{OwnerType: &operatorv1.IngressController{}}); err != nil {
 		return nil, err
 	}
+	if err := c.Watch(&source.Kind{Type: &configv1.Ingress{}}, &handler.EnqueueRequestsFromMapFunc{ToRequests: handler.ToRequestsFunc(reconciler.ingressConfigToIngressController)}); err != nil {
+		return nil, err
+	}
 	return c, nil
 }
 
+func (r *reconciler) ingressConfigToIngressController(o handler.MapObject) []reconcile.Request {
+	var requests []reconcile.Request
+	controllers := &operatorv1.IngressControllerList{}
+	if err := r.cache.List(context.Background(), controllers, client.InNamespace(r.Namespace)); err != nil {
+		log.Error(err, "failed to list ingresscontrollers for ingress", "related", o.Meta.GetSelfLink())
+		return requests
+	}
+	for _, ic := range controllers.Items {
+		log.Info("queueing ingresscontroller", "name", ic.Name, "related", o.Meta.GetSelfLink())
+		request := reconcile.Request{
+			NamespacedName: types.NamespacedName{
+				Namespace: ic.Namespace,
+				Name:      ic.Name,
+			},
+		}
+		requests = append(requests, request)
+	}
+	return requests
+}
+
 func enqueueRequestForOwningIngressController(namespace string) handler.EventHandler {
 	return &handler.EnqueueRequestsFromMapFunc{
 		ToRequests: handler.ToRequestsFunc(func(a handler.MapObject) []reconcile.Request {
@@ -575,12 +598,21 @@ func (r *reconciler) ensureIngressController(ci *operatorv1.IngressController, d
 		return fmt.Errorf("failed to ensure namespace: %v", err)
 	}
 
+	var errs []error
+	if _, _, err := r.ensureServiceCAConfigMap(); err != nil {
+		// Even if we were unable to create the configmap at this time,
+		// it is still safe try to create the deployment, as it
+		// specifies that the volume mount is non-optional, meaning the
+		// deployment will not start until the configmap exists.
+		errs = append(errs, err)
+	}
+
 	deployment, err := r.ensureRouterDeployment(ci, infraConfig, ingressConfig, apiConfig, networkConfig)
 	if err != nil {
-		return fmt.Errorf("failed to ensure deployment: %v", err)
+		errs = append(errs, fmt.Errorf("failed to ensure deployment: %v", err))
+		return utilerrors.NewAggregate(errs)
 	}
 
-	var errs []error
 	trueVar := true
 	deploymentRef := metav1.OwnerReference{
 		APIVersion: "apps/v1",
